==> alfresco-data-model-23.6.0.30-sources.jar: org/alfresco/repo/search/impl/querymodel/impl/BaseStaticArgument.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.search.impl.querymodel.impl;

import org.alfresco.repo.search.impl.querymodel.StaticArgument;

/**
 * @author andyh
 *
 */
public abstract class BaseStaticArgument extends BaseArgument implements StaticArgument
{

    /**
     * @param name String
     * @param queryable boolean
     * @param orderable boolean
     */
    public BaseStaticArgument(String name, boolean queryable, boolean orderable)
    {
        super(name, queryable, orderable);
    }


}

==> alfresco-data-model-26.1.0.5-sources.jar: org/alfresco/repo/search/impl/querymodel/impl/BaseStaticArgument.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.search.impl.querymodel.impl;

import org.alfresco.repo.search.impl.querymodel.StaticArgument;

/**
 * @author andyh
 *
 */
public abstract class BaseStaticArgument extends BaseArgument implements StaticArgument
{

    /**
     * @param name
     *            String
     * @param queryable
     *            boolean
     * @param orderable
     *            boolean
     */
    public BaseStaticArgument(String name, boolean queryable, boolean orderable)
    {
        super(name, queryable, orderable);
    }

}
